"""FaB DB tap class."""

from typing import List

from singer_sdk import Stream, Tap
from singer_sdk import typing as th

from tap_fabdb.streams import CardsStream

PLUGIN_NAME = "tap-fabdb"

STREAM_TYPES = [CardsStream]


class TapFabDb(Tap):
    """FaB DB tap class."""

    name = "tap-fabdb"

    config_jsonschema = th.PropertiesList(th.Property("api_key", th.StringType, required=False)).to_dict()

    def discover_streams(self) -> List[Stream]:
        """Return a list of discovered streams."""
        return [stream_class(tap=self) for stream_class in STREAM_TYPES]


cli = TapFabDb.cli



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['tap_fabdb', 'tap_fabdb.tests']

package_data = \
{'': ['*']}

install_requires = \
['singer-sdk>=0.3.6,<0.4.0']

entry_points = \
{'console_scripts': ['tap-fabdb = tap_fabdb.tap:TapFabDb.cli']}

setup_kwargs = {
    'name': 'tap-fabdb',
    'version': '0.0.2',
    'description': 'A Singer tap for extracting data from the FaB DB API, built with the Singer SDK.',
    'long_description': '<p align="center">\n    <em>tap-fabdb, a Singer tap for extracting data from the <a href="https://fabdb.net/resources/api" target="_blank">FaB DB API</a>.</em>\n</p>\n<p align="center">\n  <a href="https://badge.fury.io/py/tap-fabdb">\n    <img src="https://badge.fury.io/py/tap-fabdb.svg" alt="PyPI version" height="18">\n  </a>\n  <a href="https://github.com/dwallace0723/tap-fabdb/actions">\n    <img src="https://github.com/dwallace0723/tap-fabdb/actions/workflows/test.yml/badge.svg"  alt="GitHub Actions" />\n  </a>\n  <a href="https://github.com/dwallace0723/tap-fabdb/actions">\n    <img src="https://github.com/dwallace0723/tap-fabdb/actions/workflows/release.yml/badge.svg"  alt="GitHub Actions" />\n  </a>\n  <a href="https://github.com/dwallace0723/tap-fabdb/actions">\n    <img src="https://github.com/dwallace0723/tap-fabdb/actions/workflows/publish.yml/badge.svg"  alt="GitHub Actions" />\n  </a>\n  <a href="https://codeclimate.com/github/dwallace0723/tap-fabdb/maintainability">\n    <img src="https://api.codeclimate.com/v1/badges/875607d70a6dc02a82df/maintainability" />\n  </a>\n  <a href="https://codeclimate.com/github/dwallace0723/tap-fabdb/test_coverage">\n    <img src="https://api.codeclimate.com/v1/badges/875607d70a6dc02a82df/test_coverage" />\n  </a>\n  <a href="https://github.com/psf/black">\n    <img src="https://img.shields.io/badge/code%20style-black-000000.svg"  alt="Black" />\n  </a>\n</p>',
    'author': 'David Wallace',
    'author_email': 'david.wallace@dutchie.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.6.2,<3.10',
}


setup(**setup_kwargs)
